@@ -9,6 +9,7 @@ from onapsdk.configuration import settings
 from onapsdk.onap_service import OnapService
 from onapsdk.utils.headers_creator import headers_aai_creator
 from onapsdk.utils.jinja import jinja_env
+from onapsdk.utils.gui import GuiItem, GuiList
 
 from onapsdk.exceptions import RelationshipNotFound, ResourceNotFound
 
@@ -46,7 +47,6 @@ class Relationship:
                 return data["relationship-value"]
         return None
 
-
 class AaiElement(OnapService):
     """Mother Class of all A&AI elements."""
 
@@ -60,12 +60,12 @@ class AaiElement(OnapService):
     def filter_none_key_values(cls, dict_to_filter: Dict[str, Optional[str]]) -> Dict[str, str]:
         """Filter out None key values from dictionary.
 
-        Iterate throught given dictionary and filter None values.
+        Iterate through given dictionary and filter None values.
 
         Args:
             dict_to_filter (Dict): Dictionary to filter out None
 
-        Returns:
+        Returns:dataclasse init a field
             Dict[str, str]: Filtered dictionary
 
         """
@@ -78,7 +78,7 @@ class AaiElement(OnapService):
         """Resource's url.
 
         Returns:
-            str: Resource's url
+            str: Resource's urldataclasse init a field
 
         """
         raise NotImplementedError
@@ -95,10 +95,11 @@ class AaiElement(OnapService):
 
         """
         try:
-            for relationship in self.send_message_json("GET",
-                                                       "Get object relationships",
-                                                       f"{self.url}/relationship-list")\
-                                                        .get("relationship", []):
+            generator = self.send_message_json("GET",
+                                               "Get object relationships",
+                                               f"{self.url}/relationship-list")\
+                                                   .get("relationship", [])
+            for relationship in generator:
                 yield Relationship(
                     related_to=relationship.get("related-to"),
                     relationship_label=relationship.get("relationship-label"),
@@ -112,7 +113,6 @@ class AaiElement(OnapService):
                    f'Server: {self.server}. Url: {self.url}')
             raise RelationshipNotFound(msg) from exc
 
-
     def add_relationship(self, relationship: Relationship) -> None:
         """Add relationship to aai resource.
 
@@ -124,9 +124,27 @@ class AaiElement(OnapService):
         """
         self.send_message(
             "PUT",
-            "add relationship to cloud region",
+            f"add relationship to {self.__class__.__name__}",
             f"{self.url}/relationship-list/relationship",
             data=jinja_env()
             .get_template("aai_add_relationship.json.j2")
             .render(relationship=relationship),
         )
+
+    @classmethod
+    def get_guis(cls) -> GuiItem:
+        """Retrieve the status of the AAI GUIs.
+
+        Only one GUI is referenced for AAI
+        the AAI sparky GUI
+
+        Return the list of GUIs
+        """
+        gui_url = settings.AAI_GUI_SERVICE
+        aai_gui_response = cls.send_message(
+            "GET", "Get AAI GUI Status", gui_url)
+        guilist = GuiList([])
+        guilist.add(GuiItem(
+            gui_url,
+            aai_gui_response.status_code))
+        return guilist
