@@ -1,7 +1,8 @@
 """Service instance module."""
 
-from typing import Iterator, Type, Union, Iterable
+from typing import Iterator, Type, Union, Iterable, Optional
 
+from onapsdk.sdc.service import Service
 from onapsdk.so.deletion import ServiceDeletionRequest
 from onapsdk.so.instantiation import NetworkInstantiation, VnfInstantiation
 from onapsdk.exceptions import StatusError, ParameterError
@@ -100,6 +101,7 @@ class ServiceInstance(Instance):  # pylint: disable=too-many-instance-attributes
         self.persona_model_version: str = persona_model_version
         self.widget_model_id: str = widget_model_id
         self.widget_model_version: str = widget_model_version
+        self._sdc_service: Optional[Service] = None
 
     def __repr__(self) -> str:
         """Service instance object representation.
@@ -198,6 +200,20 @@ class ServiceInstance(Instance):  # pylint: disable=too-many-instance-attributes
         """
         return self._get_related_instance(PnfInstance, "pnf")
 
+    @property
+    def sdc_service(self) -> Service:
+        """Sdc service related with that instance.
+
+        Sdc service model which was used to create that instance.
+
+        Raises:
+            ResourceNotFound: Service model not found
+
+        """
+        if not self._sdc_service:
+            self._sdc_service = Service.get_by_unique_uuid(self.model_invariant_id)
+        return self._sdc_service
+
     def add_vnf(self,  # pylint: disable=too-many-arguments
                 vnf: "Vnf",
                 line_of_business: "LineOfBusiness",
@@ -205,7 +221,10 @@ class ServiceInstance(Instance):  # pylint: disable=too-many-instance-attributes
                 cloud_region: "CloudRegion" = None,
                 tenant: "Tenant" = None,
                 vnf_instance_name: str = None,
-                vnf_parameters: Iterable["InstantiationParameter"] = None) -> "VnfInstantiation":
+                vnf_parameters: Iterable["InstantiationParameter"] = None,
+                so_vnf: "SoServiceVnf" = None,
+                a_la_carte: bool = True
+                ) -> "VnfInstantiation":
         """Add vnf into service instance.
 
         Instantiate VNF.
@@ -228,6 +247,8 @@ class ServiceInstance(Instance):  # pylint: disable=too-many-instance-attributes
                 Defaults to None.
             vnf_parameters (Iterable[InstantiationParameter], optional): InstantiationParameter to
                 be passed as "userParams". Defaults to None.
+            so_vnf: (SoServiceVnf, optional): object with vnf instance parameters. Defaults to None.
+            a_la_carte (bool): instantiation type for vnf. Defaults to True.
 
         Raises:
             StatusError: Service orchestration status is not "Active".
@@ -241,7 +262,21 @@ class ServiceInstance(Instance):  # pylint: disable=too-many-instance-attributes
         if self.orchestration_status != required_status:
             msg = f'Service orchestration status must be "{required_status}"'
             raise StatusError(msg)
-        return VnfInstantiation.instantiate_ala_carte(
+
+        if a_la_carte:
+            return VnfInstantiation.instantiate_ala_carte(
+                self,
+                vnf,
+                line_of_business,
+                platform,
+                cloud_region=cloud_region,
+                tenant=tenant,
+                vnf_instance_name=vnf_instance_name,
+                vnf_parameters=vnf_parameters,
+                sdc_service=self.sdc_service
+            )
+
+        return VnfInstantiation.instantiate_macro(
             self,
             vnf,
             line_of_business,
@@ -249,7 +284,9 @@ class ServiceInstance(Instance):  # pylint: disable=too-many-instance-attributes
             cloud_region=cloud_region,
             tenant=tenant,
             vnf_instance_name=vnf_instance_name,
-            vnf_parameters=vnf_parameters
+            vnf_parameters=vnf_parameters,
+            so_vnf=so_vnf,
+            sdc_service=self.sdc_service
         )
 
     def add_network(self,  # pylint: disable=too-many-arguments
